mosaik.exceptions — mosaik specific error types — mosaik 2.3.1 documentation

# `mosaik.exceptions` — mosaik specific error types

This module provides mosaik specific exception types.

class `mosaik.exceptions.` `ScenarioError`

  This exception is raised if something fails during the creationg of a scenario.

class `mosaik.exceptions.` `SimulationError`(msg, exc=None)

  This exception is raised if a simulator cannot be started or if a problem arises during the execution of a simulation.